BluetoothPrinter class abstract

Abstract class defining the Bluetooth printer interface.

Implementers

Constructors

BluetoothPrinter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isConnected → Future<bool>
Checks if a device is currently connected.
no setter
isScanningStream → Stream<bool>
Stream indicating if the printer is scanning.
no setter
peripheralsStream → Stream<List<Peripheral>>
Stream providing updates on discovered peripherals.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusStream → Stream<PrinterStatus>
Stream providing status updates of the printer.
no setter

Methods

connect(String uuid) → Future<void>
Connects to a Bluetooth device with the given uuid.
cutPaper() → Future<void>
Cuts the paper.
disconnect() → Future<void>
Disconnects from the currently connected Bluetooth device.
isScanning() → Future<bool>
Checks if the printer is currently scanning.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBarcode(String content, {PBarcodeType type = PBarcodeType.code39, PStringEncoding encoding = PStringEncoding.utf8}) → Future<void>
Prints a barcode with the given content.
printImage(String base64Encoded, double width) → Future<void>
Prints an image from a base64 encoded string.
printQrCode(String code, {int unitSize = 5, QRErrLevel errLevel = QRErrLevel.L, PStringEncoding encoding = PStringEncoding.utf8}) → Future<void>
Prints a QR code with the given code.
printText(String text, {PTextAlign align = PTextAlign.left, PTextAttribute attribute = PTextAttribute.normal, PTextW width = PTextW.w1, PTextH height = PTextH.h1}) → Future<void>
Prints the provided text with specified formatting options.
startScan() → Future<void>
Starts scanning for Bluetooth devices.
stopScan() → Future<void>
Stops scanning for Bluetooth devices.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → BluetoothPrinter
Provides access to the singleton instance.
no setter