Peripheral class

Represents a peripheral device.

Constructors

Peripheral({String? name, String? uuid, int? stateStr})
Peripheral.fromJson(Map<String, dynamic> json)
Creates a Peripheral instance from a JSON map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → PeripheralState
Gets the PeripheralState based on stateCode.
no setter
stateStr → int?
final
uuid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited