PrinterStatus class

Represents the status of a printer.

Constructors

PrinterStatus({required int statusInt, String? uuid, String? statusMessage})
PrinterStatus.fromJson(Map<String, dynamic> json)
Creates a PrinterStatus instance from a JSON map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → PeripheralStatus
Gets the PeripheralStatus based on statusCode.
no setter
statusInt → int
final
statusMessage → String?
final
uuid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited